import { type Injector, type Signal } from '@angular/core';
import { type Action } from '@ngrx/store';
import type { SelectSignalOptions } from '@ngrx/store/src/models';
import type { ThunkAction } from '@reduxjs/toolkit';
import type { BaseQueryFn, EndpointDefinitions, Module, MutationDefinition, PrefetchOptions, QueryArgFrom, QueryDefinition, QueryKeys } from '@reduxjs/toolkit/query';
import { type HooksWithUniqueNames, type MutationHooks, type QueryHooks } from './types';
export declare const angularHooksModuleName: unique symbol;
export type AngularHooksModule = typeof angularHooksModuleName;
export type Dispatch = <ReturnType>(action: Action | ThunkAction<ReturnType, any, any, Action>) => ReturnType extends Action ? Action : ReturnType;
declare module '@reduxjs/toolkit/query' {
    interface ApiModules<BaseQuery extends BaseQueryFn, Definitions extends EndpointDefinitions, ReducerPath extends string, TagTypes extends string> {
        [angularHooksModuleName]: {
            /**
             *  Endpoints based on the input endpoints provided to `createApi`, containing `select`, `hooks` and `action matchers`.
             */
            endpoints: {
                [K in keyof Definitions]: Definitions[K] extends QueryDefinition<any, any, any, any, any> ? QueryHooks<Definitions[K]> : Definitions[K] extends MutationDefinition<any, any, any, any, any> ? MutationHooks<Definitions[K]> : never;
            };
            /**
             * A hook that accepts a string endpoint name, and provides a callback that when called,
             * pre-fetches the data for that endpoint.
             */
            usePrefetch<EndpointName extends QueryKeys<Definitions>>(endpointName: EndpointName, options?: PrefetchOptions): (arg: QueryArgFrom<Definitions[EndpointName]>, options?: PrefetchOptions) => void;
            /**
             * Provides access to the api dispatch function.
             */
            dispatch: Dispatch;
            /**
             * Provides access to the api injector.
             */
            injector: Injector;
        } & HooksWithUniqueNames<Definitions>;
    }
}
declare const _createSelector: (...input: any[]) => import("@ngrx/store").MemoizedSelector<any, any, import("@ngrx/store").DefaultProjectorFn<any>>;
export interface AngularHooksModuleOptions {
    /**
     * The hooks from Redux to be used
     */
    hooks?: {
        /**
         * The version of the `dispatch` to be used
         */
        dispatch: Dispatch;
        /**
         * The version of the `getState` to be used
         */
        getState: () => any;
        /**
         * The version of the `useSelector` hook to be used
         */
        useSelector: <K>(mapFn: (state: any) => K, options?: SelectSignalOptions<K>) => Signal<K>;
    };
    /**
     * A selector creator (usually from `reselect`, or matching the same signature)
     */
    createSelector?: typeof _createSelector;
}
/**
 * Creates a module that generates angular hooks from endpoints, for use with `buildCreateApi`.
 *
 *  @example
 * ```ts
 * const customCreateApi = buildCreateApi(
 *   coreModule(),
 *   angularHooksModule({
 *     hooks: {
 *       dispatch: createDispatchHook(MyContext),
 *       getState: createSelectorHook(MyContext),
 *       useSelector: createStoreHook(MyContext)
 *     }
 *   })
 * );
 * ```
 *
 * @returns A module for use with `buildCreateApi`
 */
export declare const angularHooksModule: ({ hooks, createSelector, }?: AngularHooksModuleOptions) => Module<AngularHooksModule>;
export {};
